@@ -60,14 +60,17 @@ typedef struct _CtkDisplayConfig
     NvCtrlAttributeHandle *handle;
     CtkConfig *ctk_config;
 
+    gboolean page_selected; /* Is the display config page selected in the UI */
 
     /* Layout */
     nvLayoutPtr layout;
     GtkWidget *obj_layout;
+    GtkWidget *label_layout;
 
     GtkWidget *chk_xinerama_enabled;
     GtkWidget *chk_primary_display;
 
+    GtkWidget *notebook; /* Tabbed notebook for display and X screen pages */
 
     /* Display - Info */
     GtkWidget *display_page;
@@ -124,8 +127,8 @@ typedef struct _CtkDisplayConfig
     GtkWidget *btn_screen_metamode;
     GtkWidget *btn_screen_metamode_add;
     GtkWidget *btn_screen_metamode_delete;
-
-
+    
+    char *screen_depth_table;
     /* Dialogs */
     GtkWidget *dlg_display_config;
     GtkWidget *rad_display_config_disabled;
@@ -171,6 +174,12 @@ typedef struct _CtkDisplayConfig
     /* Buttons */
     GtkWidget *btn_apply;
     gboolean apply_possible; /* True if all modifications are applicable */
+
+    gboolean reset_required; /* Reser required to apply */
+    gboolean forced_reset_allowed; /* OK to reset layout w/o user input */
+    gboolean notify_user_of_reset; /* User was notified of reset requirement */
+    gboolean ignore_reset_events; /* Ignore reset-causing events */
+
     int cur_screen_pos[2]; /* Keep track of the selected X screen's position */
 
     GtkWidget *btn_save;
@@ -196,6 +205,10 @@ GtkWidget*  ctk_display_config_new       (NvCtrlAttributeHandle *,
 GtkTextBuffer *ctk_display_config_create_help(GtkTextTagTable *,
                                               CtkDisplayConfig *);
 
+void ctk_display_config_selected(GtkWidget *);
+void ctk_display_config_unselected(GtkWidget *);
+
+
 G_END_DECLS
 
 #endif /* __CTK_DISPLAYCONFIG_H__ */
