@@ -28,11 +28,10 @@
 #include "msg.h"
 #include "ctkconstants.h"
 
-#include "help_banner.h"
+#include "ctkbanner.h"
 
 #include <stdlib.h>
 
-static GtkTextTagTable *create_tag_table(void);
 static GtkTextBuffer *create_default_help(CtkHelp *ctk_help);
 static void close_button_clicked(GtkButton *button, gpointer user_data);
 static gboolean window_destroy(GtkWidget *widget, GdkEvent *event,
@@ -66,7 +65,7 @@ GType ctk_help_get_type(
     return ctk_help_type;
 }
 
-GtkWidget* ctk_help_new(GtkWidget *toggle_button)
+GtkWidget* ctk_help_new(GtkWidget *toggle_button, GtkTextTagTable *tag_table)
 {
     GObject *object;
     CtkHelp *ctk_help;
@@ -75,13 +74,10 @@ GtkWidget* ctk_help_new(GtkWidget *toggle_button)
     GtkWidget *alignment;
     GtkWidget *button;
     GtkWidget *sw;
-    GtkWidget *image;
+    GtkWidget *banner;
     GtkWidget *frame;
     GtkWidget *textview;
 
-    guint8 *image_buffer = NULL;
-    const nv_image_t *img;
-
     object = g_object_new(CTK_TYPE_HELP, NULL);
 
     ctk_help = CTK_HELP(object);
@@ -103,22 +99,8 @@ GtkWidget* ctk_help_new(GtkWidget *toggle_button)
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-    frame = gtk_frame_new(NULL);
-    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
-
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-
-    img = &help_banner_image;
-
-    image_buffer = decompress_image_data(img);
-
-    image = gtk_image_new_from_pixbuf
-        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
-                                  FALSE, 8, img->width, img->height,
-                                  img->width * img->bytes_per_pixel,
-                                  free_decompressed_image, NULL));
-    
-    gtk_container_add(GTK_CONTAINER(frame), image);
+    banner = ctk_banner_image_new(BANNER_ARTWORK_HELP);
+    gtk_box_pack_start(GTK_BOX(hbox), banner, TRUE, TRUE, 0);
     
     /* create the scroll window to hold the text viewer */
 
@@ -145,9 +127,9 @@ GtkWidget* ctk_help_new(GtkWidget *toggle_button)
     g_object_set(G_OBJECT(ctk_help->text_viewer),
                  "pixels-inside-wrap", 10, NULL);
 
-    /* create the tag table */
+    /* save the tag table */
 
-    ctk_help->tag_table = create_tag_table();
+    ctk_help->tag_table = tag_table;
 
     /* create the default help text */
     
@@ -247,7 +229,7 @@ static GtkTextBuffer *create_default_help(CtkHelp *ctk_help)
 }
 
 
-static GtkTextTagTable *create_tag_table(void)
+GtkTextTagTable *ctk_help_create_tag_table(void)
 {
     GtkTextTagTable *table;
     GtkTextTag *tag;
@@ -352,12 +334,9 @@ static gboolean window_destroy(GtkWidget *widget, GdkEvent *event,
 void ctk_help_title(GtkTextBuffer *buffer, GtkTextIter *iter,
                     const gchar *fmt, ...)
 {
-    va_list ap;
     gchar *a, *b;
 
-    va_start(ap, fmt);
-    a = nv_build_vararg_string(fmt, ap);
-    va_end(ap);
+    NV_VSNPRINTF(a, fmt);
 
     b = g_strconcat("\n", a, "\n", NULL);
 
@@ -370,12 +349,9 @@ void ctk_help_title(GtkTextBuffer *buffer, GtkTextIter *iter,
 void ctk_help_para(GtkTextBuffer *buffer, GtkTextIter *iter,
                    const gchar *fmt, ...)
 {     
-    va_list ap;
     gchar *a, *b;
 
-    va_start(ap, fmt);
-    a = nv_build_vararg_string(fmt, ap);
-    va_end(ap);
+    NV_VSNPRINTF(a, fmt);
 
     b = g_strconcat("\n", a, "\n", NULL);
 
@@ -388,12 +364,9 @@ void ctk_help_para(GtkTextBuffer *buffer, GtkTextIter *iter,
 void ctk_help_heading(GtkTextBuffer *buffer, GtkTextIter *iter,
                       const gchar *fmt, ...)
 {
-    va_list ap;
     gchar *a, *b;
 
-    va_start(ap, fmt);
-    a = nv_build_vararg_string(fmt, ap);
-    va_end(ap);
+    NV_VSNPRINTF(a, fmt);
 
     b = g_strconcat("\n", a, "\n", NULL);
 
@@ -406,12 +379,9 @@ void ctk_help_heading(GtkTextBuffer *buffer, GtkTextIter *iter,
 void ctk_help_term(GtkTextBuffer *buffer, GtkTextIter *iter,
                    const gchar *fmt, ...)
 {
-    va_list ap;
     gchar *a, *b;
 
-    va_start(ap, fmt);
-    a = nv_build_vararg_string(fmt, ap);
-    va_end(ap);
+    NV_VSNPRINTF(a, fmt);
 
     b = g_strconcat("\n", a, NULL);
     
